<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_BE" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>mislukt om de database account te openen</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation>Account instellingen</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Gelieve het server adres in te vullen</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 is geen geldig server adres</translation>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation>Mislukt om de account informatie op te slaan</translation>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation>Mislukt om aanpassingen op te slaan: %1</translation>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation>Huidige account informatie succesvol geüpdatet</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Server Address</source>
        <translation>Server adres</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation>Mislukt om het synchroniseren van deze account te stoppen: %1</translation>
    </message>
    <message>
        <source>click to open the website</source>
        <translation>klik om de website te openen</translation>
    </message>
    <message>
        <source>pro version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No account</source>
        <translation>Geen account</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Account settings</source>
        <translation>Account instellingen</translation>
    </message>
    <message>
        <source>Login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Voeg een account toe</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>not logged in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulier</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <source>email</source>
        <translation>email</translation>
    </message>
    <message>
        <source>server</source>
        <translation>server</translation>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>probeer opnieuw</translation>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation>Mislukt om de activiteiten informatie te krijgen. Gelieve%1</translation>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation>Mislukt om de avatars map te maken</translation>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>Download taken</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation>verwijder alle succesvolle taken</translation>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation>Momenteel geen download taken.</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>Bibliotheek</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Pad</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>Annuleer deze taak</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>annuleer deze taak</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>Verwijder deze taak</translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Mislukt om deze taak te annuleren:

%1</translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>Mislukt om deze taak te verwijderen:

%1</translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>Minimaliseren</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Bibliotheken</translation>
    </message>
    <message>
        <source>Starred</source>
        <translation>Favoriet</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation>Activiteiten</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>current download rate</source>
        <translation>huidige downloadsnelheid</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>huidige uploadsnelheid</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation>Gelieve een te synchroniseren map te kiezen</translation>
    </message>
    <message>
        <source>no server connected</source>
        <translation>geen server verbonden</translation>
    </message>
    <message>
        <source>all servers connected</source>
        <translation>alle servers verbonden</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>enkele servers zijn niet verbonden</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulier</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>minimaliseren</translation>
    </message>
    <message>
        <source>close</source>
        <translation>sluiten</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selecteer</translation>
    </message>
    <message>
        <source>brand</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation>of Plaats Map om te Synchroniseren</translation>
    </message>
    <message>
        <source>download rate</source>
        <translation>downloadsnelheid</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation>pijlomlaag</translation>
    </message>
    <message>
        <source>upload rate</source>
        <translation>uploadsnelheid</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation>pijlomhoog</translation>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation>Fout tijdens het aanmaken van ccnet configuratie</translation>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>mislukt om %1 te lezen</translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>Aanmaken bibliotheek</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Gelieve een map te kiezen</translation>
    </message>
    <message>
        <source>Creating...</source>
        <translation>Aanmaken...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation>Gelieve de te synchroniseren map te kiezen</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>De map %1 bestaat niet</translation>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>Gelieve de naam in te vullen</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Gelieve het paswoord in te vullen</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>Paswoorden komen niet overeen</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Mislukt om download taak toe te voegen:
%1</translation>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation>Mislukt om een bibliotheek aan te maken op de server:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Pad:</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Kies</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>versleuteld</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Paswoord:</translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>Nogmaals Paswoord:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>status tekst</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>%1 client failed to initialize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 exited unexpectedly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>Gelieve het paswoord in te vullen</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>Synchronisatie bibliotheek &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Mislukt om download taak toe te voegen:
%1</translation>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation>Mislukt om de repo download informatie te halen:
%1</translation>
    </message>
    <message>
        <source>Download Library</source>
        <translation>Download Bibliotheek</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>kies...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>Paswoord voor deze bibliotheek:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation>Aanpassingen Details</translation>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Modified files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Added folders</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation>Cloud Bestand Browser</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Verder</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Startpagina</translation>
    </message>
    <message>
        <source>Upload files</source>
        <translation>Bestanden uploaden</translation>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation>Een map uploaden</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation>Je hebt geen toelating om bestanden naar deze bibliotheek te uploaden</translation>
    </message>
    <message>
        <source>Create a folder</source>
        <translation>Maak een map</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder name</source>
        <translation>Map naam</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Ongeldige map naam!</translation>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation>De naam &quot;%1&quot; is reeds in gebruik.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>probeer opnieuw</translation>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation>Mislukt om bestand informatie te krijgen&lt;br /&gt;Gelieve %1</translation>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation>Bestand %1 bestaat reeds.&lt;br/&gt;Wil je dit overschrijven?&lt;br/&gt;&lt;small&gt;(Kies Nee om te uploaden onder een andere naam).&lt;/small&gt;</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation>Mislukt om bestand te downloaden: %1</translation>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation>Kies een bestand om te uploaden</translation>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation>Kies een map om te uploaden</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Hernoemen</translation>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation>Ben je zeker dat je deze items wilt verwijderen</translation>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation>Aanmaken map is mislukt</translation>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation>Kies een bestand om te updaten %1</translation>
    </message>
    <message>
        <source>Rename failed</source>
        <translation>Hernoemen is mislukt</translation>
    </message>
    <message>
        <source>Remove failed</source>
        <translation>Verwijderen is mislukt</translation>
    </message>
    <message>
        <source>Share failed</source>
        <translation>Delen is mislukt</translation>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation>Kan geen bestanden uit dezelfde map plakken</translation>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy failed</source>
        <translation>Kopiëren is mislukt</translation>
    </message>
    <message>
        <source>Move failed</source>
        <translation>Verplaatsen is mislukt</translation>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get link</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation>Uploaden %1</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Downloaden %1</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 van %2</translation>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File save failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserSearchModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserSearchView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation>Handeling geannuleerd</translation>
    </message>
    <message>
        <source>pending</source>
        <translation>in behandeling</translation>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Interne Server Fout</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation>Laatste Aanpassing</translation>
    </message>
    <message>
        <source>Modifier</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Hernoem</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Verwijder</translation>
    </message>
    <message>
        <source>Share to Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>&amp;Update</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieer</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>S&amp;nij</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Plak</translation>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FinderSyncHost</name>
    <message>
        <source>Failed to get link</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation>Mislukt om mappen te maken</translation>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation>Mislukt op tijdelijke bestanden te maken</translation>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation>Mislukt om bestand naar de schijf te schrijven</translation>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation>Mislukt om de oude versie van het gedownloade bestand te verwijderen</translation>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation>Mislukt om bestand te verplaatsen</translation>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>%1 Initialisatie</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Gelieve een map te kiezen</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation>Initialisatie is nog niet gedaan. Zeker dat u wil stoppen?</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>De map %1 bestaat niet</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Kies...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation>Controleer je standaard bibliotheek...</translation>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation>Aanmaken standaard bibliotheek...</translation>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation>Mislukt om de standaard bibliotheek aan te maken:

De server versie moet minstens 2.1 of hoger zijn om dit te ondersteunen.</translation>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation>Mislukt om de standaard bibliotheek te halen:
%1</translation>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation>Mislukt om de standaard bibliotheek aan te maken:
%1</translation>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation>Downloaden standaard bibliotheek...</translation>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation>Mislukt om de standaard bibliotheek te downloaden:
%1</translation>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation>De standaard bibliotheek werd gedownload.
Je kan op &quot;Open&quot; klikken om het te bekijken.</translation>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation>Fout tijdens het downloaden van de standaard bibliotheek: %1</translation>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation>Mislukt op de standaard bibliotheek te downloaden:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation>Overslaan</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Draaien in Achtergrond</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Klaar</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>Download Standaard Bibliotheek</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogDirUploader</name>
    <message>
        <source>Upload log files failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload log files failed :%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Successfully uploaded log files</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogUploadProgressDialog</name>
    <message>
        <source>Compressing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Voeg een account toe</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Inloggen...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Netwerk Fout:
%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Waarschuwing:&lt;/b&gt; Het ssl certificaat van deze server is niet betrouwbaar, toch doorgaan?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Gelieve het server adres in te vullen</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 is geen geldig server adres</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Gelieve de gebruikersnaam in te vullen</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Vul de computernaam in</translation>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>Mislukt om de huidige account op te slaan</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Gelieve het paswoord in te vullen</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>Foute email of paswoord</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Te snel ingelogd, wacht een minuutje</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Interne Server Fout</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Mislukt om in te loggen: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Mislukt om in te loggen</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Bijvoorbeeld: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>of http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Paswoord:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>status tekst</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Computernaam:</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>v.b. Jim&apos;s laptop</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Automatic Login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add an account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>Vernieuwen</translation>
    </message>
</context>
<context>
    <name>MessagePoller</name>
    <message>
        <source>&quot;%1&quot; is unsynced. 
Reason: Deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by another user. Update to this file is not uploaded.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update to file %1 is denied by folder permission setting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync. 
Access denied to service</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync.
The library owner&apos;s storage space is used up.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share To:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation>gesynchroniseerd</translation>
    </message>
    <message>
        <source>indexing files</source>
        <translation>indexeren bestanden</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>initialisatie synchronisatie</translation>
    </message>
    <message>
        <source>downloading</source>
        <translation>bezig met downloaden</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>bezig met uploaden</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation>synchronisatie samenvoeging</translation>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation>wachten ome te synchroniseren</translation>
    </message>
    <message>
        <source>server not connected</source>
        <translation>server niet verbonden</translation>
    </message>
    <message>
        <source>server authenticating</source>
        <translation>server authenticatie</translation>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation>auto synchronisatie is uitgeschakeld</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>onbekend</translation>
    </message>
    <message>
        <source>Server has been removed</source>
        <translation>Server werd verwijderd</translation>
    </message>
    <message>
        <source>You have not logged in to the server</source>
        <translation>Je bent niet ingelogd op de server</translation>
    </message>
    <message>
        <source>You do not have permission to access this library</source>
        <translation>Je hebt geen toelating voor toegang tot deze bibliotheek</translation>
    </message>
    <message>
        <source>The storage space of the library owner has been used up</source>
        <translation>De opslagruimte van eigenaar van de bibliotheek is opgebruikt</translation>
    </message>
    <message>
        <source>Remote service is not available</source>
        <translation>Remote service is niet beschikbaar</translation>
    </message>
    <message>
        <source>Access denied to service</source>
        <translation>Toegang geweigerd tot de service</translation>
    </message>
    <message>
        <source>Internal data corrupted</source>
        <translation>Interne gegevens beschadigd</translation>
    </message>
    <message>
        <source>Failed to start upload</source>
        <translation>Mislukt op de upload te starten</translation>
    </message>
    <message>
        <source>Failed to start download</source>
        <translation>Mislukt om de download te starten</translation>
    </message>
    <message>
        <source>Library is damaged on server</source>
        <translation>Bibliotheek is beschadigd op de server</translation>
    </message>
    <message>
        <source>Conflict in merge</source>
        <translation>Conflict in samenvoeging</translation>
    </message>
    <message>
        <source>Server version is too old</source>
        <translation>Server versie is te oud</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>De opslag quota is opgebruikt</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>Interne server fout</translation>
    </message>
    <message>
        <source>Your %1 client is too old</source>
        <translation>Je %1 client is te oud</translation>
    </message>
    <message>
        <source>Failed to sync this library</source>
        <translation>Mislukt om deze bibliotheek te synchroniseren</translation>
    </message>
    <message>
        <source>Files are locked by other application</source>
        <translation>Bestanden werden geblokkeerd door andere toepassing</translation>
    </message>
    <message>
        <source>Library is deleted on server</source>
        <translation>Bibliotheek werd verwijderd op de server</translation>
    </message>
    <message>
        <source>Error when accessing the local folder</source>
        <translation>Fout bij openen lokale map</translation>
    </message>
    <message>
        <source>initializing...</source>
        <translation>initialisatie...</translation>
    </message>
    <message>
        <source>Failed to index local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to check server information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to merge local file changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect password. Please download again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>connecting server...</source>
        <translation>verbinden met server...</translation>
    </message>
    <message>
        <source>indexing files...</source>
        <translation>indexatie bestanden...</translation>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>Aanmaken map...</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation>Samenvoegen aanpassingen bestand...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
    <message>
        <source>checking server info...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceling</source>
        <translation>Annulatie</translation>
    </message>
    <message>
        <source>Canceled</source>
        <translation>Geannuleerd</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>SSL Fout</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Netwerk Fout: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Server Fout</translation>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation>mislukt om de certs databank te openen</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation>%1 kon geen toepassing vinden om het bestand %2 te openen</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Aanmaken bibliotheek &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Bbibliotheek &quot;%1&quot; verwijderd</translation>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation>Hernoem %1 naar</translation>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation>Kan item &quot;%1&quot; niet downloaden</translation>
    </message>
    <message>
        <source>copy failed</source>
        <translation>kopiëren is mislukt</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Toegevoegd</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Verwijderd</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Verwijderd</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Aangepast</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Hernoemd</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moved</source>
        <translation>Verplaatst</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Map toegevoegd</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Map verwijderd</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Map hernoemd</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Map verplaatst</translation>
    </message>
    <message>
        <source>files</source>
        <translation>bestanden</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>mappen</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>en %1 meer</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Bibliotheek teruggezet naar status van</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>Bestand &quot;%1&quot; teruggezet naar status van %2.</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Terugplaatsen verwijderde map</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Bibliotheek naam of beschrijving aangepast</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Just now</source>
        <translation>Nu</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>1 dag geleden</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>%1 dagen geleden</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 uur geleden</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 uren geleden</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>1 minuut geleden</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minuten geleden</translation>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation>&lt;Geen Deel van Certificaat&gt;</translation>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PDF Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Text Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audio File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Word Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Excel Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update to file denied by folder permission setting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Client is already running</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error occurred in upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error occurred in download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission denied on server. Please try to resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try to resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not have write permission to the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not have permission to sync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No permission to sync this folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>Bbiliotheek &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation>Deze bibliotheek werd nog niet gedownload</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Fout:</translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation>RepoIcon</translation>
    </message>
    <message>
        <source>RepoName</source>
        <translation>RepoName</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschrijving:</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Eigenaar:</translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>Laatst Aangepast:</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation>mtime</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Grootte:</translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>Lokaal Pad:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation>RepoStatus</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>, %1</source>
        <translation>, %1</translation>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation>Deze bibliotheek werd niet gedownload</translation>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation>Recentelijk Aangepast</translation>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>Mijn Bibliotheken</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>Onderverdeling Bibiliotheken</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation>Gesynchroniseerde Bibliotheken</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Uitschakelen auto sync</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Inschakelen auto sync</translation>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation>Toon de details van deze bibliotheek</translation>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation>&amp;Synchroniseer deze bibliotheek</translation>
    </message>
    <message>
        <source>Sync this library</source>
        <translation>Synchroniseer deze bibliotheek</translation>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation>Recentelijk Aangepast</translation>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation>Synchroniseer deze bibliotheek onmiddellijk</translation>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>&amp;Cancel download</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation>Annulatie download van deze bibliotheek</translation>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>&amp;Open map</translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation>open lokale map</translation>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation>&amp;Unsync</translation>
    </message>
    <message>
        <source>unsync this library</source>
        <translation>annulatie synchronisatie van deze bibliotheek</translation>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation>&amp;Bekijk in de cloud</translation>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation>Bekijk deze bibliotheek op seahub</translation>
    </message>
    <message>
        <source>Share to user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation>&amp;Hersynchroniseer deze bibliotheek opnieuw</translation>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation>annulatie synchronisatie en hersynchronisatie van deze bibliotheek</translation>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation>Mislukt om synchronisatie van bibliotheek &quot;%1&quot; te annuleren</translation>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Mislukt om deze taak te annuleren:

%1</translation>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation>De download werd geannuleerd</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation>Kan bestand &quot;%1&quot; niet verwijderen</translation>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation>Mislukt om bestand te uploaden: %1</translation>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>probeer opnieuw</translation>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation>Mislukt om bestand informatie te krijgen&lt;br /&gt;Gelieve %1</translation>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Waarschuwing:&lt;/b&gt; Het ssl certificaat van deze server is niet betrouwbaar, toch doorgaan?</translation>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation>Mislukt om de log te initialiseren: %s</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to save client id</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to access %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>incorrect client id</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Internal Link:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>internal error: failed to connect to daemon</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Uitschakelen auto sync</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Inschakelen auto synchronisatie</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation>Toon hoofdvenster</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>&amp;Log map openen</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hierover</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Toon de toepassings&apos; Hierover kader</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Online help</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation>auto synchronisatie is uitgeschakeld</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation>Uploaden</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>enkele servers zijn niet verbonden</translation>
    </message>
    <message>
        <source>Upload log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>upload %1 log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please login first</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>Servers verbindingsstatus</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>verbonden</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>verbinding verbroken</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation>Geef het bibliotheek paswoord</translation>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation>Geef het paswoord voor bibliotheek %1</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Vul het paswoord in</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>Onjuist paswoord</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation>Je hebt de taal veranderd. Herstarten om dit toe te passen?</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation>Verberg hoofdvenster na start</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Melden wanneer bibliotheken gesynchroniseerd zijn</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Activeren synchronisatie van tijdelijke bestanden MSOffice/Libreoffice</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Download snelheid limiet (KB/s):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Upload snelheid limiet (KB/s):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Basis</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation>Annuleer niet automatisch het synchroniseren van een bibliotheek</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation>Annuleer niet automatisch het synchroniseren van een bibliotheek als de lokale map verwijderd is of om andere redenen niet toegankelijk is.</translation>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation>Annuleer het synchroniseren van een bibliotheek niet wanneer deze niet gevonden wordt op een server</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation>Annuleer niet automatisch het synchroniseren van een bibliotheek wanneer deze niet gevondenn wordt op een server</translation>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>Controleer het server certificaat in HTTPS synchronisatie niet</translation>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Taal (herstart vereist)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password:</source>
        <translation>Paswoord:</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove Share</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Deel Link</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Deel link:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopieer naar klembord</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation>Onvertrouwde Verbinding</translation>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation>%1 gebruikt een ongeldig veiligheidscertificaat. De verbinding kan onveilig zijn. Wil je verdergaan?</translation>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation>Huidige RSA sleutel vingerafdruk is %1</translation>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation>Vorige RSA sleutel vingerafdruk is %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Onthou mijn keuze</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nee</translation>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Open</translation>
    </message>
    <message>
        <source>Open this file</source>
        <translation>Open dit bestand</translation>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation>bekijk op &amp;Web</translation>
    </message>
    <message>
        <source>view this file on website</source>
        <translation>bekijk dit bestand op de website</translation>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation>probeer opnieuw</translation>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation>Mislukt om informatie van favoriete bestanden te bekijken&lt;br/&gt;Gelieve %1</translation>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation>Je hebt nog geen favoriete bestanden.</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TwoFactorDialog</name>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>mText</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember this device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Desinstalleer %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Wil je de %1 account info verwijderen?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Verwijdering account info...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>text</source>
        <translation>tekst</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nee</translation>
    </message>
</context>
</TS>